@@ -320,6 +320,16 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1> inline void set_imag(const Base<pod_type,T1>& X);
   
   
+  inline eT min() const;
+  inline eT max() const;
+  
+  inline eT min(u32& index_of_min_val) const;
+  inline eT max(u32& index_of_max_val) const;
+  
+  inline eT min(u32& row_of_min_val, u32& col_of_min_val) const;
+  inline eT max(u32& row_of_max_val, u32& col_of_max_val) const;
+  
+  
   inline bool save(const std::string   name, const file_type type = arma_binary, const bool print_status = true) const;
   inline bool save(      std::ostream& os,   const file_type type = arma_binary, const bool print_status = true) const;
   
